@@ -121,13 +121,11 @@ def run():
     popupmenu.onquit(gtk.main_quit)
 
     statusicon = StatusIcon(title)
-    statusicon.connect("activate", statusicon_activate(window))
-    statusicon.connect("popup-menu", statusicon_popupmenu(popupmenu))
+    statusicon.set_menu(popupmenu)
 
     if engine.settings.show_at_startup:
         window.show_all()
         window.present()
-    statusicon.set_visible(True)
 
     try:
         gtk.main()
